@@ -10,3 +10,5 @@
 from detector_connector.detector_connector import DetectorConnector
 from detector_connector.detector_http_connector import DetectorHttpConnector
 from detector_connector.detector_kafka_connector import DetectorKafkaConnector
+from detector_connector.detector_kafka_connector import AnalyzeResultCallback
+from detector_connector.detector_kafka_connector import DetectionAnalyzeResult
