@@ -8,7 +8,6 @@
 
 
 from dataclasses import dataclass
-import json
 
 from http_tools.http_server_connector import HttpServerConnector
 
@@ -26,14 +25,14 @@ class DetectorHttpConnector:
         self._connector = HttpServerConnector(config, context)
 
     async def correct_settings(self, stream_url: str, correct_file_id: str, token: str) -> bool:
-        payload = json.dumps(
-            {
+        payload = {
                 "correct_file_id": correct_file_id,
                 "token": token,
                 "stream_url": stream_url
-            }
-        ).encode()
-        answer = await self._connector.post("/settings/correct", payload=payload, headers=self._construct_headers())
+        }
+        answer = await self._connector.post_json("/settings/correct",
+                                                 payload=payload,
+                                                 headers=self._construct_headers())
         return answer["done"]
 
     def _construct_headers(self) -> dict[str, str]:
